jQuery UI Sortable - Include / exclude items

### Specify which items are sortable:

- Item 1
- (I'm not sortable or a drop target)
- (I'm not sortable or a drop target)
- Item 4

### Cancel sorting (but keep as drop targets):

- Item 1
- (I'm not sortable)
- (I'm not sortable)
- Item 4

Specify which items are eligible to sort by passing a jQuery selector into the `items` option. Items excluded from this option are not sortable, nor are they valid targets for sortable items.

To only prevent sorting on certain items, pass a jQuery selector into the `cancel` option. Cancelled items remain valid sort targets for others.